export default {
	//通用Post请求方法
	Post: function(url, data = {}, isloading = false) {
		var promise = new Promise(function(resolve, reject) {
			//判断是否需要显示加载状态
			if (isloading) {
				uni.showLoading({
					title: '加载中...'
				})
			}
			uni.request({
				url: url,
				data: data,
				method: 'POST',
				sslVerify: false,
				header: {
					'content-type': 'application/json',
					// 'token': uni.getStorageSync('token') ? uni.getStorageSync('token') : '',
				},
				success: function(data) {
					if (isloading) {
						uni.hideLoading()
					}
					if (data.data.code == 1) {
						resolve(data.data);
					} else if (data.data.code == 0) {
						uni.showModal({
							title: '系统提示',
							content: data.data.msg,
							showCancel: false,
							success() {
								resolve(data.data);
							}
						})
					}
				},
				fail: function(data) {
					if (isloading) {
						uni.hideLoading();
					}
					uni.showModal({
						title: '系统提示',
						content: data.errMsg,
						showCancel: false
					});
					reject(data.errMsg);
				}
			});
		});
		return promise;
	},
	//通用Get请求方法
	Get: function(url, data = {}, isloading = false) {
		var promise = new Promise(function(resolve, reject) {
			//判断是否需要显示加载状态
			if (isloading) {
				uni.showLoading({
					title: '加载中...'
				})
			}
			uni.request({
				url: url,
				data: data,
				method: 'GET',
				header: {
					'content-type': 'application/json',
					'Authorization': uni.getStorageSync('userinfo').token
				},
				success: function(data) {
					if (isloading) {
						uni.hideLoading();
					}
					if (data.statusCode == 200) {
						resolve(data.data);
					} else {
						uni.showModal({
							title: '系统提示',
							content: '服务器请求错误',
							showCancel: false,
						});
						reject('服务器请求错误');
					}
				},
				fail: function(data) {
					if (isloading) {
						uni.hideLoading();
					}
					uni.showModal({
						title: '系统提示',
						content: data.errMsg,
						showCancel: false
					});
					reject(data.errMsg);
				}
			})
		});
		return promise;
	},
	//下载文件接口
	DownLoad: function(url, isloading = false) {
		var promise = new Promise(function(resolve, reject) {
			//判断是否需要显示加载状态
			if (isloading) {
				uni.showLoading({
					title: '加载中...'
				})
			}

			uni.downloadFile({
				url: url,
				success(res) {
					if (res.statusCode === 200) {
						if (isloading) {
							uni.hideLoading();
						}
						resolve(res.tempFilePath);
					} else {
						if (isloading) {
							uni.hideLoading();
						}
						reject('服务器请求错误');
					}
				}
			});
		});
		return promise;
	},

	//发起支付
	uniPay: function(data) {
		var promise = new Promise(function(resolve, reject) {
			//开始发起支付
			uni.requestPayment({
				timeStamp: String(data.timeStamp),
				nonceStr: data.nonceStr,
				package: data.package,
				signType: data.signType,
				paySign: data.paySign,
				success: function(res) {
					resolve(res);
				},
				fail: function(res) {
					reject(res);
				},
				complete: function(res) {}
			});
		});
		return promise;
	}
}